/* eslint-disable no-param-reassign */ import { fieldAffectsData, tabHasName } from 'payload/types';
import { getTableName } from '../schema/getTableName.js';
export const traverseFields = ({ _locales, adapter, currentArgs, currentTableName, depth, fields, path, topLevelArgs, topLevelTableName })=>{
    fields.forEach((field)=>{
        if (field.type === 'collapsible' || field.type === 'row') {
            traverseFields({
                _locales,
                adapter,
                currentArgs,
                currentTableName,
                depth,
                fields: field.fields,
                path,
                topLevelArgs,
                topLevelTableName
            });
            return;
        }
        if (field.type === 'tabs') {
            field.tabs.forEach((tab)=>{
                const tabPath = tabHasName(tab) ? `${path}${tab.name}_` : path;
                traverseFields({
                    _locales,
                    adapter,
                    currentArgs,
                    currentTableName,
                    depth,
                    fields: tab.fields,
                    path: tabPath,
                    topLevelArgs,
                    topLevelTableName
                });
            });
            return;
        }
        if (fieldAffectsData(field)) {
            switch(field.type){
                case 'array':
                    {
                        const withArray = {
                            columns: {
                                _parentID: false
                            },
                            orderBy: ({ _order }, { asc })=>[
                                    asc(_order)
                                ],
                            with: {}
                        };
                        const arrayTableName = getTableName({
                            adapter,
                            config: field,
                            parentTableName: currentTableName,
                            prefix: `${currentTableName}_${path}`
                        });
                        const arrayTableNameWithLocales = getTableName({
                            adapter,
                            config: field,
                            locales: true,
                            parentTableName: currentTableName,
                            prefix: `${currentTableName}_${path}`
                        });
                        if (adapter.tables[arrayTableNameWithLocales]) withArray.with._locales = _locales;
                        currentArgs.with[`${path}${field.name}`] = withArray;
                        traverseFields({
                            _locales,
                            adapter,
                            currentArgs: withArray,
                            currentTableName: arrayTableName,
                            depth,
                            fields: field.fields,
                            path: '',
                            topLevelArgs,
                            topLevelTableName
                        });
                        break;
                    }
                case 'select':
                    {
                        if (field.hasMany) {
                            const withSelect = {
                                columns: {
                                    id: false,
                                    order: false,
                                    parent: false
                                },
                                orderBy: ({ order }, { asc })=>[
                                        asc(order)
                                    ]
                            };
                            currentArgs.with[`${path}${field.name}`] = withSelect;
                        }
                        break;
                    }
                case 'blocks':
                    field.blocks.forEach((block)=>{
                        const blockKey = `_blocks_${block.slug}`;
                        if (!topLevelArgs[blockKey]) {
                            const withBlock = {
                                columns: {
                                    _parentID: false
                                },
                                orderBy: ({ _order }, { asc })=>[
                                        asc(_order)
                                    ],
                                with: {}
                            };
                            const tableName = getTableName({
                                adapter,
                                config: block,
                                parentTableName: topLevelTableName,
                                prefix: `${topLevelTableName}_blocks_`
                            });
                            if (adapter.tables[`${tableName}${adapter.localesSuffix}`]) {
                                withBlock.with._locales = _locales;
                            }
                            topLevelArgs.with[blockKey] = withBlock;
                            traverseFields({
                                _locales,
                                adapter,
                                currentArgs: withBlock,
                                currentTableName: tableName,
                                depth,
                                fields: block.fields,
                                path: '',
                                topLevelArgs,
                                topLevelTableName
                            });
                        }
                    });
                    break;
                case 'group':
                    traverseFields({
                        _locales,
                        adapter,
                        currentArgs,
                        currentTableName,
                        depth,
                        fields: field.fields,
                        path: `${path}${field.name}_`,
                        topLevelArgs,
                        topLevelTableName
                    });
                    break;
                default:
                    {
                        break;
                    }
            }
        }
    });
    return topLevelArgs;
};

//# sourceMappingURL=traverseFields.js.map