import { APIError } from 'payload/errors';
import toSnakeCase from 'to-snake-case';
/**
 * Used to name database enums and tables
 * Returns the table or enum name for a given entity
 */ export const getTableName = ({ adapter, config: { name, slug }, config, locales = false, parentTableName, prefix = '', relationships = false, target = 'dbName', throwValidationError = false, versions = false })=>{
    let result;
    let custom = config[target];
    if (!custom && target === 'enumName') {
        custom = config['dbName'];
    }
    if (custom) {
        result = typeof custom === 'function' ? custom({
            tableName: parentTableName
        }) : custom;
    } else {
        result = `${prefix}${toSnakeCase(name ?? slug)}`;
    }
    if (locales) result = `${result}${adapter.localesSuffix}`;
    if (versions) result = `_${result}${adapter.versionsSuffix}`;
    if (relationships) result = `${result}${adapter.relationshipsSuffix}`;
    if (!throwValidationError) {
        return result;
    }
    if (result.length > 63) {
        throw new APIError(`Exceeded max identifier length for table or enum name of 63 characters. Invalid name: ${result}`);
    }
    return result;
};

//# sourceMappingURL=getTableName.js.map